options(stringsAsFactors=FALSE, scipen=100)
library(limma)
library(GEOquery)
library(magrittr)
library(dplyr)
library(tidyr)
Sys.setenv('VROOM_CONNECTION_SIZE'=1000000000)

##-- load data --##
# phenotype
gset = getGEO(GEO='GSE66360', getGPL=FALSE, destdir='../input/')
# expression profile
geneID_exprSet = read.table('../../input/GSE66360_series_matrix.txt.gz', sep='\t', header=TRUE, comment.char='!', row.names=1, check.names=FALSE)
# GPL annotation
GPL570 = read.table('F:/Bioinformation/Transcriptome/Database/GPL数据/GPL570-55999.txt',
                    fill=TRUE, sep='\t', header=TRUE, comment.char='#', quote='', check.names=FALSE)

##-- get phenotype --##
phenotype = pData(gset$GSE66360_series_matrix.txt.gz) %>%
            select(geo_accession, title) %>%
            rename(Group=title) %>%
            mutate(Group=ifelse(grepl('Control$', Group), 'Control', 'MI'))

##-- combine data --##
# separate gene
GPL570_geneSymbol = GPL570[, c('ID', 'Gene Symbol')] %>% unique()
# expression profile
geneSymbol_exprSet = merge(GPL570_geneSymbol, geneID_exprSet, by.x='ID', by.y='row.names') %>% 
                     select(-ID) %>%
                     aggregate(.~`Gene Symbol`, ., mean) %>%
                     filter(`Gene Symbol` != '') %>%
                     rename(Symbol='Gene Symbol')
# combine EXP and phenotype
EXP_pheno = t(phenotype) %>% as.data.frame() %>% mutate(Symbol="group") %>% slice(-1) %>% rbind(geneSymbol_exprSet)
EXP_pheno = EXP_pheno[, c(ncol(EXP_pheno), 1:ncol(EXP_pheno)-1)]
# export
write.table(EXP_pheno, '../output/data/GSE66360.txt', sep='\t', quote=FALSE, row.names=FALSE)
