options(stringsAsFactors=FALSE)
library(ggstatsplot)
library(data.table)
library(dplyr)
library(tidyr)
library(ggplot2)


# 创建输出文件夹
dir.create('../output', showWarnings=FALSE)
dir.create('../output/data', showWarnings=FALSE)
dir.create('../output/picture', showWarnings=FALSE)

# 免疫细胞矩阵
GEO_cibersort = read.csv("../../1. Cibersort/output/data/GEO-cibersort.csv", row.names=1, check.names=FALSE) %>% select(-c(`P-value`, Correlation, RMSE))

# expression profile
EXP = read.table("../../1. Cibersort/output/data/GEO-EXP.txt", row.names=1, sep="\t", header=TRUE)

# hub gene
hubGenes = readxl::read_excel('../../../input/10 差异基因.xlsx', sheet='Sheet1')

#用表达量的样本名称，调整免疫矩阵的样本顺序
#这一步并不是必须，这里只是保证计算相关性的时候一一对应
EXP = EXP[, rownames(GEO_cibersort)]

# hub gnee
hubGene = hubGenes$`gene symbol`

###----------------------- each hub gene correlation with immune cell -----------------------#
for(h in hubGene){
    y = as.numeric(EXP[h, ])
    
    colnames = colnames(GEO_cibersort)
    data = data.frame(colnames)
    for(i in 1:length(colnames)){
        test = cor.test(as.numeric(GEO_cibersort[, i]), y, type="spearman")
        data[i, 2] = test$estimate                                            
        data[i, 3] = test$p.value
    }
    names(data) = c("symbol", "correlation", "pvalue")
    write.csv(data, paste0('../output/data/', h, '--immune cell.csv'), row.names=FALSE)
    
    data %>% #filter(pvalue <0.05) %>% # 如果不想把p值大于0.05的放在图上，去掉最前面的#号
         ggplot(aes(correlation, forcats::fct_reorder(symbol, correlation))) +
         geom_segment(aes(xend=0, yend=symbol)) +
         geom_point(aes(col=pvalue, size=abs(correlation))) +
         scale_colour_gradientn(colours=c("#7fc97f", "#984ea3")) +
         #scale_color_viridis_c(begin=0.5, end=1) +
         scale_size_continuous(range =c(2, 8)) +
         theme_minimal() + 
         ggtitle(h) +
         ylab(NULL)
    ggsave(paste0('../output/picture/', h, '--immune cell.pdf'), width=8, height=6)
}
